<?php

/**
 * Including other scripts
==========================================================*/
include('inc/template-tags.php');
include('inc/css-generator.php');
include('inc/customizer.php');



/**
 * Empower Setup
===================================*/
if(!function_exists('reflect_setup')){
	function reflect_setup() {
		load_theme_textdomain( 'reflect' );
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'title-tag' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'html5', array('comment-form', 'comment-list', 'gallery', 'caption'));
		add_theme_support( 'customize-selective-refresh-widgets' );
		
		// Set the default content width.
		$GLOBALS['content_width'] = apply_filters( 'reflect_content_width', 1080 );
		
		
		$register_nav_menus = array();
		$register_nav_menus['primary'] = __( 'Primary', 'reflect' );
		if(apply_filters('reflect_active_secondary_menu', false)){
			$register_nav_menus['secondary'] = __( 'Secondary', 'reflect' );
		}
		if(apply_filters('reflect_active_footer_menu', false)){
			$register_nav_menus['footer'] = __( 'Footer', 'reflect' );
		}
		register_nav_menus($register_nav_menus);
		
		add_theme_support( 'custom-logo', array(
			'width'       => apply_filters( 'reflect_logo_width', 200 ),
			'height'      => apply_filters( 'reflect_logo_height', 50 ),
			'flex-width'  => true,
		) );
		
		
		add_image_size('reflect_blog', 800, 400, true);
		
		add_theme_support(
			'post-formats', array(
				'aside',
				'image',
				'video',
				'quote',
				'link',
				'gallery',
				'audio',
			)
		);
		
	}
}
add_action( 'after_setup_theme', 'reflect_setup' );


if(!function_exists('reflect_early_setup')){
	function reflect_early_setup(){
		add_filter('reflect_active_header_top', '__return_true');
		add_filter('reflect_active_header', '__return_true');
		add_filter('reflect_active_header_bottom', '__return_true');
		add_filter('reflect_active_phone', '__return_true');
		add_filter('reflect_active_email', '__return_true');
		add_filter('reflect_active_address', '__return_true');
		add_filter('reflect_active_hours', '__return_true');
		add_filter('reflect_active_social_icons', '__return_true');
		
		add_filter('reflect_active_header_widget', '__return_true');
		//add_filter('reflect_active_secondary_menu', '__return_true');
		add_filter('reflect_active_footer_menu', '__return_true');
		add_filter('reflect_active_contact_text', '__return_true');
		
		add_filter('reflect_active_footer_top', '__return_true');
		add_filter('reflect_active_footer', '__return_true');
		add_filter('reflect_active_footer_bottom', '__return_true');
	}
}
add_action( 'after_setup_theme', 'reflect_early_setup', 1);




/**
 * Reflec Tweak
===================================*/
// Enable shortcodes in text widgets
add_filter('widget_text','do_shortcode');

function reflect_excerpt_length( $length ) {
	if(is_admin()){
		return $length;
	}else{
		return 50;
	}
}
add_filter( 'excerpt_length', 'reflect_excerpt_length', 999 );

function reflect_excerpt_more( $more ) {
	if(is_admin()){
		return $more;
	}else{
		return '';
	}
}
add_filter('excerpt_more', 'reflect_excerpt_more');




/**
 * Register sidebar
===================================*/
if(!function_exists('reflect_widgets_init')){
	function reflect_widgets_init() {
		register_sidebar( array(
			'name'          => esc_html__( 'Primary', 'reflect' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'reflect' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		));
		register_sidebar( array(
			'name'          => esc_html__( 'Pages Sidebar', 'reflect' ),
			'id'            => 'sidebar-2',
			'description'   => esc_html__( 'Add widgets here.', 'reflect' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		));
		if(apply_filters('reflect_active_header_widget', false)){
			register_sidebar( array(
				'name'          => esc_html__( 'Header', 'reflect' ),
				'id'            => 'header-1',
				'description'   => esc_html__( 'Add widgets here.', 'reflect' ),
				'before_widget' => '<section id="%1$s" class="widget %2$s">',
				'after_widget'  => '</section>',
				'before_title'  => '<h4 class="widget-title">',
				'after_title'   => '</h4>',
			));
		}
		if(apply_filters('reflect_active_footer', false)){
			register_sidebar( array(
				'name'          => esc_html__( 'Footer 1', 'reflect' ),
				'id'            => 'footer-1',
				'description'   => esc_html__( 'Add widgets here.', 'reflect' ),
				'before_widget' => '<section id="%1$s" class="widget %2$s">',
				'after_widget'  => '</section>',
				'before_title'  => '<h4 class="widget-title">',
				'after_title'   => '</h4>',
			));
			register_sidebar( array(
				'name'          => esc_html__( 'Footer 2', 'reflect' ),
				'id'            => 'footer-2',
				'description'   => esc_html__( 'Add widgets here.', 'reflect' ),
				'before_widget' => '<section id="%1$s" class="widget %2$s">',
				'after_widget'  => '</section>',
				'before_title'  => '<h4 class="widget-title">',
				'after_title'   => '</h4>',
			));
			register_sidebar( array(
				'name'          => esc_html__( 'Footer 3', 'reflect' ),
				'id'            => 'footer-3',
				'description'   => esc_html__( 'Add widgets here.', 'reflect' ),
				'before_widget' => '<section id="%1$s" class="widget %2$s">',
				'after_widget'  => '</section>',
				'before_title'  => '<h4 class="widget-title">',
				'after_title'   => '</h4>',
			));
			register_sidebar( array(
				'name'          => esc_html__( 'Footer 4', 'reflect' ),
				'id'            => 'footer-4',
				'description'   => esc_html__( 'Add widgets here.', 'reflect' ),
				'before_widget' => '<section id="%1$s" class="widget %2$s">',
				'after_widget'  => '</section>',
				'before_title'  => '<h4 class="widget-title">',
				'after_title'   => '</h4>',
			));
		}
	}
}
add_action( 'widgets_init', 'reflect_widgets_init' );



/**
 * Enqueue scripts and styles.
==========================================================*/
if(!function_exists('reflect_scripts')){
	function reflect_scripts() {
		
		// Add custom fonts, used in the main stylesheet.
		wp_enqueue_style( 'reflect-fonts', reflect_fonts_url(), array(), null );
		
		/*== Font Awesome Free ==*/
		wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/assets/fontawesome-free/web-fonts-with-css/css/fontawesome-all.css' );
	
		/*== magnific-popup ==*/
		wp_enqueue_style( 'magnific-popup', get_template_directory_uri() . '/assets/magnific-popup/magnific-popup.css' );
		wp_enqueue_script( 'magnific-popup', get_template_directory_uri() . '/assets/magnific-popup/jquery.magnific-popup.js', array('jquery'), '1.1.0', false );
		
		/*== flexibility ==*/
		wp_enqueue_script( 'flexibility', get_template_directory_uri() . '/assets/flexibility.mini.js', array('jquery'), '1.0', false );
		
		/*== fitvids ==*/
		wp_enqueue_script( 'fitvids', get_template_directory_uri() . '/assets/jquery.fitvids.js', array('jquery'), '1.1', false );
		
		/*== Theme ==*/
		wp_enqueue_style( 'reflect-core', get_template_directory_uri() . '/core.css' );
		wp_enqueue_style( 'reflect', get_stylesheet_uri() );
		wp_enqueue_script( 'reflect-js', get_template_directory_uri() . '/assets/reflect.js', array('jquery'), '1.0', false );
		
		/*== Comments ==*/
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}	
	}
}
add_action( 'wp_enqueue_scripts', 'reflect_scripts' );


/**
 * Enqueue Custom/Dynamic CSS
 */
function reflect_custom_scripts(){
	$custom_css = apply_filters('reflect_custom_css', reflect_custom_css());
	
	wp_add_inline_style( 'reflect', $custom_css );
}
add_action( 'wp_enqueue_scripts', 'reflect_custom_scripts', 11 );